clear all
clf

%% If bathymetry does not exist already in data files,
%% then it must be created from scratch

dx=0.1;
x=[0:dx:45]';
y=[0:dx:26]';
nx=length(x);
ny=length(y);

h=zeros(ny,nx);
mod=h;

z_existing=[0  0  0.5  1.0  1.0];  %coordinates for existing (pre-tongue) bottom
x_existing=[0 10 17.5 32.5 45.0];

h0=interp1(x_existing,z_existing,x);
for j=1:ny
   h(j,:)=h0';
end

z_mod=[0  0  0.7 0.75 1.0  1.0];  %coordinates for modification change
x_mod= [0 10 12.5  25 32.5 45.0];

z0=interp1(x_mod,z_mod,x);

dz0=z0-h0;

h_mod=zeros(nx,ny);
yc=y(ny)/2;  %centerline coordinate
for i=1:ny
   dist=(1-min(1,abs(y(i)-yc)/yc));
   
   z_mod=[0  0  0.7+0.05*(1-dist) 0.75 1.0  1.0];  %coordinates for modification change
	x_mod= [0 10 12.5+12.4999*(1-dist) 25 32.5 45.0];

	z0=interp1(x_mod,z_mod,x);
	z0=max(z0,h0);
	h_mod(:,i)=z0;
end

ys=yc;
xs=17;  %15.5
rs=3;
hs=.45;

x_ind=round(xs/dx)+1;
y_ind=round(ys/dx)+1;
r_ind=round(rs/dx);

h_shoal=zeros(nx,ny);
for i=x_ind-r_ind:x_ind+r_ind
   for j=y_ind-r_ind:y_ind+r_ind
      r_loc=sqrt( (x(i)-xs)^2 + (y(j)-ys)^2);
      if r_loc<rs
         h_shoal(i,j)=hs*(1-r_loc/rs);
      end
   end
end
         
h=(h_mod-0.78+h_shoal)';

h_m=(h_mod-.78)';

y=y-y(round(ny/2));

%********************************************************************
%% plot the data
figure(1)
surf(x,y,h)
shading interp
colorbar
%axis equal
axis([0 45 -13 13 -1 1])
view(20,-67)
colormap(gray)
grid off
xlabel('X (m)')
ylabel('Y (m)')
title('Bathymetry for Benchmark 2')


figure(2)
surf(x,y,h)
shading interp
colorbar
%axis equal
axis([0 45 -13 13 -1 1])
view([0 90])
colormap(jet)
colorbar
grid off
xlabel('X (m)')
ylabel('Y (m)')
title('Bathymetry for Benchmark 2')


